@@ -60,7 +60,6 @@ static void              xdg_cache_cache_move               (TumblerCache
 static gboolean          xdg_cache_cache_is_thumbnail       (TumblerCache           *cache,
                                                              const gchar            *uri);
 static GList            *xdg_cache_cache_get_flavors        (TumblerCache           *cache);
-static const gchar      *xdg_cache_cache_get_home           (void);
 
 
 
@@ -200,91 +199,68 @@ xdg_cache_cache_cleanup (TumblerCache       *cache,
       g_object_unref (parent);
       g_object_unref (dummy_file);
 
-      if (since != 0)
+      /* attempt to open the directory for reading */
+      dir = g_dir_open (dirname, 0, NULL);
+      if (dir != NULL)
         {
-          /* attempt to open the directory for reading */
-          dir = g_dir_open (dirname, 0, NULL);
-          if (dir != NULL)
+          /* iterate over all files in the directory */
+          file_basename = g_dir_read_name (dir);
+          while (file_basename != NULL)
             {
-              /* iterate over all files in the directory */
-              file_basename = g_dir_read_name (dir);
-              while (file_basename != NULL)
+              /* build the thumbnail filename */
+              filename = g_build_filename (dirname, file_basename, NULL);
+
+              /* read thumbnail information from the file */
+              if (xdg_cache_cache_read_thumbnail_info (filename, &uri, &mtime,
+                                                       NULL, NULL))
                 {
-                  /* build the thumbnail filename */
-                  filename = g_build_filename (dirname, file_basename, NULL);
-
-                  /* read thumbnail information from the file */
-                  if (xdg_cache_cache_read_thumbnail_info (filename, &uri, &mtime,
-                                                           NULL, NULL))
+                  /* check if the thumbnail information is valid or the mtime
+                   * is too old */
+                  if (uri == NULL || mtime <= since)
                     {
-                      /* check if the thumbnail information is valid or the mtime
-                       * is too old */
-                      if (uri == NULL || mtime <= since)
-                        {
-                          /* it's invalid, so let's remove the thumbnail */
-                          g_unlink (filename);
-                        }
-                      else
-                        {
-                           /* create a GFile for the original URI. we need this for
-                            * reliably checking the ancestor/descendant relationship */
-                          original_file = g_file_new_for_uri (uri);
+                      /* it's invalid, so let's remove the thumbnail */
+                      g_unlink (filename);
+                    }
+                  else
+                    {
+                      /* create a GFile for the original URI. we need this for
+                       * reliably checking the ancestor/descendant relationship */
+                      original_file = g_file_new_for_uri (uri);
 
-                          for (n = 0; base_uris != NULL && base_uris[n] != NULL; ++n)
+                      for (n = 0; base_uris != NULL && base_uris[n] != NULL; ++n)
+                        {
+                          /* create a GFile for the base URI */
+                          base_file = g_file_new_for_uri (base_uris[n]);
+
+                          /* delete the file if it is a descendant of the base URI */
+                          if (g_file_equal (original_file, base_file)
+                              || g_file_has_prefix (original_file, base_file))
                             {
-                              /* create a GFile for the base URI */
-                              base_file = g_file_new_for_uri (base_uris[n]);
-
-                              /* delete the file if it is a descendant of the base URI */
-                              if (g_file_equal (original_file, base_file)
-                                  || g_file_has_prefix (original_file, base_file))
-                                {
-                                  g_unlink (filename);
-                                }
-
-                              /* releas the base file */
-                              g_object_unref(base_file);
+                              g_unlink (filename);
                             }
 
-                          /* release the original file */
-                          g_object_unref (original_file);
+                          /* releas the base file */
+                          g_object_unref(base_file);
                         }
+
+                      /* release the original file */
+                      g_object_unref (original_file);
                     }
-
-                  /* free the thumbnail filename */
-                  g_free (filename);
-
-                  /* try to determine the next filename in the directory */
-                  file_basename = g_dir_read_name (dir);
                 }
 
-              /* close the handle used to reading from the directory */
-              g_dir_close (dir);
+              /* free the thumbnail filename */
+              g_free (filename);
+
+              /* try to determine the next filename in the directory */
+              file_basename = g_dir_read_name (dir);
             }
 
-          /* free the thumbnail flavor directory filename */
-          g_free (dirname);
+          /* close the handle used to reading from the directory */
+          g_dir_close (dir);
         }
-      /* According to the spec, mtime since can be 0 to ignore the threshold and
-       * only cleanup based on the URI prefix array. */
-      else
-        {
-          for (n = 0; base_uris != NULL && base_uris[n] != NULL; ++n)
-            {
-              base_file = xdg_cache_cache_get_file (base_uris[n], iter->data);
 
-              filename = g_file_get_path (base_file);
-              if (g_file_test (filename, G_FILE_TEST_IS_REGULAR))
-              {
-                g_unlink (filename);
-              }
-
-              g_free(filename);
-
-              /* releas the base file */
-              g_object_unref(base_file);
-            }
-        }
+      /* free the thumbnail flavor directory filename */
+      g_free (dirname);
     }
 }
 
@@ -581,14 +557,6 @@ xdg_cache_cache_get_flavors (TumblerCache *cache)
 
 
 
-static const gchar *
-xdg_cache_cache_get_home (void)
-{
-  return g_getenv ("HOME") != NULL ? g_getenv ("HOME") : g_get_home_dir ();
-}
-
-
-
 GFile *
 xdg_cache_cache_get_file (const gchar            *uri,
                           TumblerThumbnailFlavor *flavor)
